# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/runtime/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from jetpack.models.core import core_pb2 as models_dot_core_dot_core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='models/runtime/job.proto',
  package='runtime',
  syntax='proto3',
  serialized_options=b'Z\"go.jetpack.io/axiom/models/runtime',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18models/runtime/job.proto\x12\x07runtime\x1a\x16models/core/core.proto\"=\n\x03Job\x12\x1c\n\x04meta\x18\x01 \x01(\x0b\x32\x0e.core.NodeMeta\x12\x18\n\x10qualified_symbol\x18\x02 \x01(\tB$Z\"go.jetpack.io/axiom/models/runtimeb\x06proto3'
  ,
  dependencies=[models_dot_core_dot_core__pb2.DESCRIPTOR,])




_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='runtime.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='runtime.Job.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qualified_symbol', full_name='runtime.Job.qualified_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=122,
)

_JOB.fields_by_name['meta'].message_type = models_dot_core_dot_core__pb2._NODEMETA
DESCRIPTOR.message_types_by_name['Job'] = _JOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'models.runtime.job_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Job)
  })
_sym_db.RegisterMessage(Job)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .remote_pb2 import *
class RemoteExecutorStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateTask:grpc.UnaryUnaryMultiCallable[
        global___CreateTaskRequest,
        global___CreateTaskResponse] = ...

    PostResult:grpc.UnaryUnaryMultiCallable[
        global___PostResultRequest,
        global___PostResultResponse] = ...

    WaitForResult:grpc.UnaryUnaryMultiCallable[
        global___WaitForResultRequest,
        global___WaitForResultResponse] = ...

    # Sets the cron jobs associated to an app. If the list of cron jobs is
    # empty, removes all the cron jobs.
    SetCronJobs:grpc.UnaryUnaryMultiCallable[
        global___SetCronJobsRequest,
        global___SetCronJobsResponse] = ...

    # Golang prototype
    RemoteCall:grpc.UnaryUnaryMultiCallable[
        global___RemoteCallRequest,
        global___RemoteCallResponse] = ...


class RemoteExecutorServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateTask(self,
        request: global___CreateTaskRequest,
        context: grpc.ServicerContext,
    ) -> global___CreateTaskResponse: ...

    @abc.abstractmethod
    def PostResult(self,
        request: global___PostResultRequest,
        context: grpc.ServicerContext,
    ) -> global___PostResultResponse: ...

    @abc.abstractmethod
    def WaitForResult(self,
        request: global___WaitForResultRequest,
        context: grpc.ServicerContext,
    ) -> global___WaitForResultResponse: ...

    # Sets the cron jobs associated to an app. If the list of cron jobs is
    # empty, removes all the cron jobs.
    @abc.abstractmethod
    def SetCronJobs(self,
        request: global___SetCronJobsRequest,
        context: grpc.ServicerContext,
    ) -> global___SetCronJobsResponse: ...

    # Golang prototype
    @abc.abstractmethod
    def RemoteCall(self,
        request: global___RemoteCallRequest,
        context: grpc.ServicerContext,
    ) -> global___RemoteCallResponse: ...


def add_RemoteExecutorServicer_to_server(servicer: RemoteExecutorServicer, server: grpc.Server) -> None: ...
